Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon CloudSearch.

Actions, resources, and condition keys for Amazon CloudSearch - Service Authorization Reference

# Actions, resources, and condition keys for Amazon CloudSearch

Amazon CloudSearch (service prefix: `cloudsearch` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon CloudSearch
- Resource types defined by Amazon CloudSearch
- Condition keys for Amazon CloudSearch

## Actions defined by Amazon CloudSearch

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTags | Attaches resource tags to an Amazon CloudSearch domain | Tagging | domain* |  |
BuildSuggesters | Indexes the search suggestions | Write | domain* |  |
CreateDomain | Creates a new search domain | Write | domain* |  |
DefineAnalysisScheme | Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options | Write | domain* |  |
DefineExpression | Configures an Expression for the search domain | Write | domain* |  |
DefineIndexField | Configures an IndexField for the search domain | Write | domain* |  |
DefineSuggester | Configures a suggester for a domain | Write | domain* |  |
DeleteAnalysisScheme | Deletes an analysis scheme | Write | domain* |  |
DeleteDomain | Permanently deletes a search domain and all of its data | Write | domain* |  |
DeleteExpression | Removes an Expression from the search domain | Write | domain* |  |
DeleteIndexField | Removes an IndexField from the search domain | Write | domain* |  |
DeleteSuggester | Deletes a suggester | Write | domain* |  |
DescribeAnalysisSchemes | Gets the analysis schemes configured for a domain | Read | domain* |  |
DescribeAvailabilityOptions | Gets the availability options configured for a domain | Read | domain* |  |
DescribeDomainEndpointOptions | Gets the domain endpoint options configured for a domain | Read | domain* |  |
DescribeDomains | Gets information about the search domains owned by this account | List | domain* |  |
DescribeExpressions | Gets the expressions configured for the search domain | Read | domain* |  |
DescribeIndexFields | Gets information about the index fields configured for the search domain | Read | domain* |  |
DescribeScalingParameters | Gets the scaling parameters configured for a domain | Read | domain* |  |
DescribeServiceAccessPolicies | Gets information about the access policies that control access to the domain's document and search endpoints | Read | domain* |  |
DescribeSuggesters | Gets the suggesters configured for a domain | Read | domain* |  |
IndexDocuments | Tells the search domain to start indexing its documents using the latest indexing options | Write | domain* |  |
ListDomainNames | Lists all search domains owned by an account | List | domain* |  |
ListTags | Displays all of the resource tags for an Amazon CloudSearch domain | Read | domain* |  |
RemoveTags | Removes the specified resource tags from an Amazon ES domain | Tagging | domain* |  |
UpdateAvailabilityOptions | Configures the availability options for a domain | Write | domain* |  |
UpdateDomainEndpointOptions | Configures the domain endpoint options for a domain | Write | domain* |  |
UpdateScalingParameters | Configures scaling parameters for a domain | Write | domain* |  |
UpdateServiceAccessPolicies | Configures the access rules that control access to the domain's document and search endpoints | Permissions management | domain* |  |
document [permission only] | Allows access to the document service operations | Write | domain |  |
search [permission only] | Allows access to the search operations | Read | domain |  |
suggest [permission only] | Allows access to the suggest operations | Read | domain |  |

## Resource types defined by Amazon CloudSearch

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

###### Note

For information about using Amazon CloudSearch resource ARNs in an IAM policy, see Amazon CloudSearch ARNs in the Amazon CloudSearch Developer Guide .

Resource types | ARN | Condition keys
--- | --- | ---
domain | `arn:$ { Partition}:cloudsearch:$ { Region}:$ { Account}:domain/$ { DomainName}` |

## Condition keys for Amazon CloudSearch

CloudSearch has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.